[jboss-svn-commits] JBoss Common SVN: r3671 - in shrinkwrap/trunk: api/src/main/java/org/jboss/shrinkwrap/api/importer and 1 other directories.

jboss-svn-commits at lists.jboss.org jboss-svn-commits at lists.jboss.org
Wed Nov 11 10:16:58 EST 2009


Author: ALRubinger
Date: 2009-11-11 10:16:58 -0500 (Wed, 11 Nov 2009)
New Revision: 3671

Added:
   shrinkwrap/trunk/api/src/main/java/org/jboss/shrinkwrap/api/importer/ArchiveImportException.java
Removed:
   shrinkwrap/trunk/api/src/main/java/org/jboss/shrinkwrap/api/importer/ArchiveImporterException.java
Modified:
   shrinkwrap/trunk/api/src/main/java/org/jboss/shrinkwrap/api/exporter/ArchiveExportException.java
   shrinkwrap/trunk/api/src/main/java/org/jboss/shrinkwrap/api/importer/ZipImporter.java
   shrinkwrap/trunk/impl-base/src/main/java/org/jboss/shrinkwrap/impl/base/importer/ZipImporterImpl.java
Log:
[SHRINKWRAP-73] Require Throwable cause on import/export exceptions.  Rename import exception for consistency.

Modified: shrinkwrap/trunk/api/src/main/java/org/jboss/shrinkwrap/api/exporter/ArchiveExportException.java
===================================================================
--- shrinkwrap/trunk/api/src/main/java/org/jboss/shrinkwrap/api/exporter/ArchiveExportException.java	2009-11-11 15:15:54 UTC (rev 3670)
+++ shrinkwrap/trunk/api/src/main/java/org/jboss/shrinkwrap/api/exporter/ArchiveExportException.java	2009-11-11 15:16:58 UTC (rev 3671)
@@ -29,21 +29,11 @@
 
    private static final long serialVersionUID = 1L;
 
-   public ArchiveExportException()
-   {
-      super();
-   }
-
    public ArchiveExportException(String message, Throwable cause)
    {
       super(message, cause);
    }
 
-   public ArchiveExportException(String message)
-   {
-      super(message);
-   }
-
    public ArchiveExportException(Throwable cause)
    {
       super(cause);

Copied: shrinkwrap/trunk/api/src/main/java/org/jboss/shrinkwrap/api/importer/ArchiveImportException.java (from rev 3668, shrinkwrap/trunk/api/src/main/java/org/jboss/shrinkwrap/api/importer/ArchiveImporterException.java)
===================================================================
--- shrinkwrap/trunk/api/src/main/java/org/jboss/shrinkwrap/api/importer/ArchiveImportException.java	                        (rev 0)
+++ shrinkwrap/trunk/api/src/main/java/org/jboss/shrinkwrap/api/importer/ArchiveImportException.java	2009-11-11 15:16:58 UTC (rev 3671)
@@ -0,0 +1,42 @@
+/*
+ * JBoss, Home of Professional Open Source
+ * Copyright 2009, Red Hat Middleware LLC, and individual contributors
+ * by the @authors tag. See the copyright.txt in the distribution for a
+ * full listing of individual contributors.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * http://www.apache.org/licenses/LICENSE-2.0
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+package org.jboss.shrinkwrap.api.importer;
+
+/**
+ * ArchiveImportException
+ * 
+ * Exception thrown on error while mporting a Archive.
+ *
+ * @author <a href="mailto:aslak at conduct.no">Aslak Knutsen</a>
+ * @version $Revision: $
+ */
+public class ArchiveImportException extends RuntimeException
+{
+
+   private static final long serialVersionUID = 1L;
+   
+   public ArchiveImportException(String message, Throwable cause)
+   {
+      super(message, cause);
+   }
+
+   public ArchiveImportException(Throwable cause)
+   {
+      super(cause);
+   }
+
+}

Deleted: shrinkwrap/trunk/api/src/main/java/org/jboss/shrinkwrap/api/importer/ArchiveImporterException.java
===================================================================
--- shrinkwrap/trunk/api/src/main/java/org/jboss/shrinkwrap/api/importer/ArchiveImporterException.java	2009-11-11 15:15:54 UTC (rev 3670)
+++ shrinkwrap/trunk/api/src/main/java/org/jboss/shrinkwrap/api/importer/ArchiveImporterException.java	2009-11-11 15:16:58 UTC (rev 3671)
@@ -1,52 +0,0 @@
-/*
- * JBoss, Home of Professional Open Source
- * Copyright 2009, Red Hat Middleware LLC, and individual contributors
- * by the @authors tag. See the copyright.txt in the distribution for a
- * full listing of individual contributors.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- * http://www.apache.org/licenses/LICENSE-2.0
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-package org.jboss.shrinkwrap.api.importer;
-
-/**
- * ArchiveImporterException
- * 
- * Exception thrown if error importing a Archive.
- *
- * @author <a href="mailto:aslak at conduct.no">Aslak Knutsen</a>
- * @version $Revision: $
- */
-public class ArchiveImporterException extends RuntimeException
-{
-
-   private static final long serialVersionUID = 1L;
-
-   public ArchiveImporterException()
-   {
-      super();
-   }
-
-   public ArchiveImporterException(String message, Throwable cause)
-   {
-      super(message, cause);
-   }
-
-   public ArchiveImporterException(String message)
-   {
-      super(message);
-   }
-
-   public ArchiveImporterException(Throwable cause)
-   {
-      super(cause);
-   }
-
-}

Modified: shrinkwrap/trunk/api/src/main/java/org/jboss/shrinkwrap/api/importer/ZipImporter.java
===================================================================
--- shrinkwrap/trunk/impl-base/src/main/java/org/jboss/shrinkwrap/impl/base/importer/ZipImporterImpl.java	2009-11-11 15:15:54 UTC (rev 3670)
+++ shrinkwrap/trunk/impl-base/src/main/java/org/jboss/shrinkwrap/impl/base/importer/ZipImporterImpl.java	2009-11-11 15:16:58 UTC (rev 3671)
@@ -24,7 +24,7 @@
 import java.util.zip.ZipInputStream;
 
 import org.jboss.shrinkwrap.api.Archive;
-import org.jboss.shrinkwrap.api.importer.ArchiveImporterException;
+import org.jboss.shrinkwrap.api.importer.ArchiveImportException;
 import org.jboss.shrinkwrap.api.importer.ZipImporter;
 import org.jboss.shrinkwrap.impl.base.SpecializedBase;
 import org.jboss.shrinkwrap.impl.base.Validate;
@@ -108,7 +108,7 @@
       }
       catch (IOException e) 
       {
-         throw new ArchiveImporterException("Could not import stream", e);
+         throw new ArchiveImportException("Could not import stream", e);
       }
       finally 
       {



More information about the jboss-svn-commits mailing list
--- shrinkwrap/trunk/api/src/main/java/org/jboss/shrinkwrap/api/importer/ZipImporter.java	2009-11-11 15:15:54 UTC (rev 3670)
+++ shrinkwrap/trunk/api/src/main/java/org/jboss/shrinkwrap/api/importer/ZipImporter.java	2009-11-11 15:16:58 UTC (rev 3671)
@@ -38,16 +38,16 @@
     * 
     * @param stream the stream to import
     * @return Archive of the imported Zip
     * @throws ArchiveImporterException if IOException during import
     */
-   ZipImporter importZip(ZipInputStream stream) throws ArchiveImporterException;
+   ZipImporter importZip(ZipInputStream stream) throws ArchiveImportException;
    
    /**
     * Imports provided {@link ZipInputStream} as a {@link Archive}.
     * 
     * @param file the file to import
     * @return Archive of the imported Zip
     * @throws ArchiveImporterException if IOException during import
     */
-   ZipImporter importZip(ZipFile file) throws ArchiveImporterException;
+   ZipImporter importZip(ZipFile file) throws ArchiveImportException;
 }
@@ -38,16 +38,16 @@
     * @param stream the stream to import
     * @return Archive of the imported Zip
-    * @throws ArchiveImporterException if IOException during import
+    * @throws ArchiveImportException if IOException during import
     */
@@ -38,16 +38,16 @@
     * @param file the file to import
     * @return Archive of the imported Zip
-    * @throws ArchiveImporterException if IOException during import
+    * @throws ArchiveImportException if IOException during import
     */

Modified: shrinkwrap/trunk/impl-base/src/main/java/org/jboss/shrinkwrap/impl/base/importer/ZipImporterImpl.java
===================================================================